#!/usr/bin/env python

from MoinMessage import *
from email.mime.text import MIMEText
import sys

if __name__ == "__main__":
    try:
        signer = sys.argv[1]
        recipient = sys.argv[2]
        i = 3
        if sys.argv[i] == "--to":
            to = sys.argv[i+1]
            i += 2
        else:
            to = None
        if sys.argv[i] == "--forward":
            forwarder = sys.argv[i+1]
            i += 2
        else:
            forwarder = None
        url = sys.argv[i] + "?action=PostMessage"
        type = sys.argv[i+1]
        action = sys.argv[i+2]
        args = sys.argv[i+3:]
    except IndexError:
        args = None

    if not args:
        print >>sys.stderr, "Need a signer, recipient, URL, update type, action and some updates as arguments to this program."
        print >>sys.stderr, "Syntax:"
        print >>sys.stderr, sys.argv[0], "<signing keyid> <recipient keyid> " \
                                         "[ --forward <signing keyid> ] <URL> " \
                                         "<update type> <action> <update>..."
        sys.exit(1)

    message = Message()
    parts = []

    for arg in args:
        part = MIMEText(arg, "moin", sys.stdin.encoding)
        if type == "collection":
            part["Update-Action"] = action
            message.add_update(part)
        else:
            parts.append(part)

    if type != "collection":
        multipart = message.get_update(parts)
        multipart["Update-Action"] = action
        message.add_update(multipart)

    email_message = message.get_payload()
    gpg = GPG()

    try:
        signed_message = gpg.signMessage(email_message, signer)
        message_to_send = gpg.encryptMessage(signed_message, recipient)

        # Forwarded messages should be timestamped and must be directed to a
        # message store.

        if forwarder:
            timestamp(message_to_send)
            message_to_send["Update-Action"] = "store"
            message_to_send = gpg.signMessage(message_to_send, forwarder)

        # An explicit recipient can also be added.

        if to:
            message_to_send["To"] = to

        resp = sendMessage(message_to_send, url)
        print resp

    except MoinMessageError, exc:
        print >>sys.stderr, exc

# vim: tabstop=4 expandtab shiftwidth=4
